summaryrefslogtreecommitdiffstats
path: root/src/H5Tbit.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Tbit.c')
-rw-r--r--src/H5Tbit.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/H5Tbit.c b/src/H5Tbit.c
index 3f8e5f9..f85ff14 100644
--- a/src/H5Tbit.c
+++ b/src/H5Tbit.c
@@ -185,7 +185,7 @@ H5T_bit_shift(uint8_t *buf, ssize_t shift_dist, size_t offset, size_t size)
H5WB_t *wb = NULL; /* Wrapped buffer for temporary buffer */
herr_t ret_value = SUCCEED; /* Return value */
- FUNC_ENTER_NOAPI(H5T_bit_shift, FAIL)
+ FUNC_ENTER_NOAPI(FAIL)
/* Sanity check */
HDassert(buf);
@@ -259,7 +259,7 @@ H5T_bit_get_d(uint8_t *buf, size_t offset, size_t size)
size_t i, hs;
uint64_t ret_value; /* Return value */
- FUNC_ENTER_NOAPI_NOFUNC(H5T_bit_get_d)
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(8 * sizeof(val) >= size);
@@ -417,8 +417,8 @@ H5T_bit_find(uint8_t *buf, size_t offset, size_t size, H5T_sdir_t direction,
size_t iu;
ssize_t ret_value = (-1); /* Return value */
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5T_bit_find)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
/* Some functions call this with value=TRUE */
HDassert(TRUE == 1);
@@ -522,8 +522,8 @@ H5T_bit_inc(uint8_t *buf, size_t start, size_t size)
unsigned carry = 1;
unsigned acc, mask;
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5T_bit_inc)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(buf);
@@ -593,8 +593,8 @@ H5T_bit_dec(uint8_t *buf, size_t start, size_t size)
uint8_t tmp;
unsigned borrow = 0;
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5T_bit_dec)
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(buf);
HDassert(size);
@@ -668,8 +668,8 @@ H5T_bit_neg(uint8_t *buf, size_t start, size_t size)
size_t pos = start % 8;
uint8_t tmp[1];
- /* Use FUNC_ENTER_NOAPI_NOINIT_NOFUNC here to avoid performance issues */
- FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5T_bit_neg);
+ /* Use FUNC_ENTER_NOAPI_NOINIT_NOERR here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOERR
HDassert(buf);
HDassert(size);